@@ -11,8 +11,6 @@ This module provide the core objects for controlling ParFlow.
 import os
 import sys
 import argparse
-import shutil
-import subprocess
 
 from . import settings
 from .fs import get_absolute_path
@@ -22,6 +20,7 @@ from .terminal import Symbols as termSymbol
 from .database.generated import BaseRun, PFDBObj, PFDBObjListNumber
 from .export import SubsurfacePropertiesExporter
 
+
 def check_parflow_execution(out_file):
     """Helper function that can be used to parse ParFlow output file
 
@@ -45,7 +44,8 @@ def check_parflow_execution(out_file):
             else:
                 emoji = f'{termSymbol.x} '
                 print(
-                    f'# ParFlow run failed. {emoji*3} Contents of error output file:')
+                    f'# ParFlow run failed. {emoji*3} '
+                    f'Contents of error output file:')
                 print("-"*80)
                 print(contents)
                 print("-"*80)
@@ -56,6 +56,7 @@ def check_parflow_execution(out_file):
 
 # -----------------------------------------------------------------------------
 
+
 def get_current_parflow_version():
     """Helper function to extract ParFlow version
 
@@ -77,11 +78,13 @@ def get_current_parflow_version():
                 print(f'Cannot find version in {version_file}')
     else:
         print(
-            f'Cannot find environment file in {os.path.abspath(version_file)}.')
+            f'Cannot find environment file in '
+            f'{os.path.abspath(version_file)}.')
     return version
 
 # -----------------------------------------------------------------------------
 
+
 def get_process_args():
     """
     General processing of script arguments
@@ -141,24 +144,29 @@ def get_process_args():
                         default=False,
                         dest="validation_error",
                         action='store_true',
-                        help="Only print validation results for key/value pairs with errors")
+                        help="Only print validation results for "
+                             "key/value pairs with errors")
     # ++++++++++++++++
     group = parser.add_argument_group('Parallel execution')
     group.add_argument("-p", type=int, default=0,
                         dest="p",
-                        help="P allocates the number of processes to the grid-cells in x")
+                        help="P allocates the number of processes "
+                             "to the grid-cells in x")
     group.add_argument("-q", type=int, default=0,
                         dest="q",
-                        help="Q allocates the number of processes to the grid-cells in y")
+                        help="Q allocates the number of processes "
+                             "to the grid-cells in y")
     group.add_argument("-r", type=int, default=0,
                         dest="r",
-                        help="R allocates the number of processes to the grid-cells in z")
+                        help="R allocates the number of processes "
+                             "to the grid-cells in z")
 
     args, unknown = parser.parse_known_args()
     return args
 
 # -----------------------------------------------------------------------------
 
+
 def update_run_from_args(run, args):
     """
     Push processed args onto run properties.
@@ -190,6 +198,7 @@ def update_run_from_args(run, args):
 
 # -----------------------------------------------------------------------------
 
+
 class Run(BaseRun):
     """Main object that can be used to define a ParFlow simulation
 
@@ -306,7 +315,8 @@ class Run(BaseRun):
         print()
         error_count = 0
         if not (skip_validation or self._process_args_.skipValidation):
-            skip_valid = True if self._process_args_.validation_error else False
+            skip_valid = True if self._process_args_.validation_error \
+                else False
             error_count += self.validate(skip_valid=skip_valid)
             print()
 
@@ -315,10 +325,6 @@ class Run(BaseRun):
         r = self.Process.Topology.R
         num_procs = p * q * r
 
-        # subprocess.run(
-        #     ['/bin/sh', '$PARFLOW_DIR/bin/run', run_file, str(num_procs)],
-        #     cwd=PFDBObj.working_directory
-        # )
         success = True
         if not self._process_args_.dry_run:
             os.chdir(settings.WORKING_DIRECTORY)
@@ -354,4 +360,3 @@ class Run(BaseRun):
         from parflowio.pyParflowio import PFData
         pfb_data = PFData(pfb_file_full_path)
         pfb_data.distFile(p, q, r, pfb_file_full_path)
-
